# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/boomee/deal/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/boomee/deal/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Boomee\\Deal\\": "packages/boomee/deal/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Boomee\Deal\Providers\DealServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Deal'  => Boomee\Deal\Facades\Deal::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Boomee\\DealTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Boomee\Deal\Providers\DealServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Boomee\Deal\Providers\DealServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Boomee\Deal\Providers\DealServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/deal/{modulename}

**User**

    http://path-to-route-folder/user/deal/{modulename}

**Public**

    http://path-to-route-folder/deals


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/deal/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/deal/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/deal/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/deal/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/deal/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/deal/{modulename}/{slug}
    METHOD: GET